==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/encryption_otr/translations/encryption_otr_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Create private key started</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>Create private key finished</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Enable private messaging</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatically initiate private messaging</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Require private messaging</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Use account&apos;s policy</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Enable private messaging</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatically initiate private messaging</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Require private messaging</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Start Private Conversation</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>End Private Conversation</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Verify Peer Identity</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Refresh Private Conversation</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>Unverified</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Private</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>Not Private</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Error occurred during message encryption</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>You sent encrypted data to %1, who wasn&apos;t expecting it</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>You transmitted an unreadable encrypted message</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>You transmitted a malformed data message</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Encryption error. Message was not sent.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Error during setting up private conversation with %1: %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>Last message was resent: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>Message from %1 was unreadable, as you are not currently communicating privately.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>Message from %1 was unreadable.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>Message from %1 was malformed.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Encryption error: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>Message from %1 was unencrypted.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>Message from %1 was unrecognized.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Malformed message received</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[resent]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: trying to start private conversation</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: trying to refresh private conversation</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: peer ended private conversation; you should do the same</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: private conversation started</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: private conversation stopped</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: conversation is still private</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: creating private key, it can took a few minutes</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: private key created, you can start a private conversation now</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: private key creation failed</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Fingerprint Exchange</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Your Key Fingerprint (%1: %2):</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>I&apos;m not sure if above Key Fingerprint belongs to %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>I confirm that above Key Fingerprint belongs to %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Verification Progress</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Verification in progres...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Ask Question</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Question and Answer</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Question that only %1 can answer:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Answer:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Answer Question</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Respond to Question and Answer</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 wants to verify your identity using Question and Answer method.</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>%1 question:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Answer:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Send Shared Secret</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Respond to Shared Secret</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 wants to verify your identity using Shared Secret method.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Shared Secret that is known only for you and %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Verification Result</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>%1 has verified you. You should do the same.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>Verification of %1 succeeded.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Unknown.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Select Verification Method</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Question and Answer</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Shared Secred</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Fingerprint Exchange</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Ask for Shared Secret</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Shared Secret</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Shared Secret that is known only for you and %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Verify Identity of %1</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/encryption_otr/translations/encryption_otr_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Create private key started</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>Create private key finished</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Enable private messaging</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatically initiate private messaging</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Require private messaging</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Use account&apos;s policy</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Enable private messaging</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Automatically initiate private messaging</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Require private messaging</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Start Private Conversation</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>End Private Conversation</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Verify Peer Identity</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Refresh Private Conversation</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>Unverified</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Private</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>Not Private</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Error occurred during message encryption</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>You sent encrypted data to %1, who wasn&apos;t expecting it</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>You transmitted an unreadable encrypted message</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>You transmitted a malformed data message</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Encryption error. Message was not sent.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Error during setting up private conversation with %1: %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>Last message was resent: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>Message from %1 was unreadable, as you are not currently communicating privately.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>Message from %1 was unreadable.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>Message from %1 was malformed.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Encryption error: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>Message from %1 was unencrypted.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>Message from %1 was unrecognized.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Malformed message received</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[resent]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>OTR Encryption</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: trying to start private conversation</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: trying to refresh private conversation</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: peer ended private conversation; you should do the same</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: private conversation started</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: private conversation stopped</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: conversation is still private</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: creating private key, it can took a few minutes</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: private key created, you can start a private conversation now</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: private key creation failed</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Fingerprint Exchange</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Your Key Fingerprint (%1: %2):</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>I&apos;m not sure if above Key Fingerprint belongs to %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>I confirm that above Key Fingerprint belongs to %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Verification Progress</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Verification in progres...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Ask Question</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Question and Answer</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Question that only %1 can answer:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Answer:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Answer Question</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Respond to Question and Answer</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 wants to verify your identity using Question and Answer method.</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>%1 question:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Answer:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Send Shared Secret</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Respond to Shared Secret</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 wants to verify your identity using Shared Secret method.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Shared Secret that is known only for you and %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Verification Result</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>%1 has verified you. You should do the same.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>Verification of %1 succeeded.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Unknown.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Select Verification Method</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Question and Answer</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Shared Secred</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Fingerprint Exchange</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Ask for Shared Secret</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Shared Secret</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Shared Secret that is known only for you and %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Verify Identity of %1</translation>
    </message>
</context>
</TS>
